@@ -1,7 +1,6 @@
+import copy
 from datetime import datetime, timezone
 import requests
-import json
-import copy
 from typing import List, Dict
 
 from .constants import (
@@ -62,13 +61,7 @@ class _BulkEventsChunk:
         self.response = None
 
     def __get_url(self):
-        url_template = "{}event/"
-        if self.config.include_signature_param:
-            if self.config.auth_enabled:
-                url_template = url_template + "?verify=true"
-            else:
-                url_template = url_template + "?verify=false"
-        url_formatted = url_template.format(self.config.base_url)
+        url_formatted = "{}event/".format(self.config.base_url)
         return url_formatted
 
     def __common_headers(self):
@@ -125,14 +118,10 @@ class _BulkEventsChunk:
 
     def trigger(self):
         headers = {**self.__headers, **self.__dynamic_headers()}
-        # Based on whether signature is required or not, add Authorization header
-        if self.config.auth_enabled:
-            # Signature and Authorization-header
-            content_txt, sig = get_request_signature(self.__url, 'POST', self.__chunk, headers,
-                                                     self.config.workspace_secret)
-            headers["Authorization"] = "{}:{}".format(self.config.workspace_key, sig)
-        else:
-            content_txt = json.dumps(self.__chunk, ensure_ascii=False)
+        # Signature and Authorization-header
+        content_txt, sig = get_request_signature(self.__url, 'POST', self.__chunk, headers,
+                                                 self.config.workspace_secret)
+        headers["Authorization"] = "{}:{}".format(self.config.workspace_key, sig)
         # -----
         try:
             resp = requests.post(self.__url,
